class Example:
    """Example class"""

    num_attribute = 5
    text_attribute = 'string'

    relevance = 'testing'
    """attribute docstring"""
